package com.sun.org.apache.xml.internal.serialize;

import java.io.InputStream;
import java.security.PrivilegedActionException;
import java.io.FileNotFoundException;
import java.security.PrivilegedExceptionAction;
import java.io.FileInputStream;
import java.io.File;
import java.security.AccessController;
import java.security.PrivilegedAction;

final class SecuritySupport
{
    private static final SecuritySupport securitySupport;
    
    static SecuritySupport getInstance() {
        return SecuritySupport.securitySupport;
    }
    
    ClassLoader getContextClassLoader() {
        return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                ClassLoader cl = null;
                try {
                    cl = Thread.currentThread().getContextClassLoader();
                }
                catch (SecurityException ex) {}
                return cl;
            }
        });
    }
    
    ClassLoader getSystemClassLoader() {
        return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                ClassLoader cl = null;
                try {
                    cl = ClassLoader.getSystemClassLoader();
                }
                catch (SecurityException ex) {}
                return cl;
            }
        });
    }
    
    ClassLoader getParentClassLoader(final ClassLoader cl) {
        return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                ClassLoader parent = null;
                try {
                    parent = cl.getParent();
                }
                catch (SecurityException ex) {}
                return (parent == cl) ? null : parent;
            }
        });
    }
    
    String getSystemProperty(final String propName) {
        return (String)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return System.getProperty(propName);
            }
        });
    }
    
    FileInputStream getFileInputStream(final File file) throws FileNotFoundException {
        try {
            return (FileInputStream)AccessController.doPrivileged(new PrivilegedExceptionAction() {
                @Override
                public Object run() throws FileNotFoundException {
                    return new FileInputStream(file);
                }
            });
        }
        catch (PrivilegedActionException e) {
            throw (FileNotFoundException)e.getException();
        }
    }
    
    InputStream getResourceAsStream(final ClassLoader cl, final String name) {
        return (InputStream)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                if (cl == null) {
                    InputStream ris = ClassLoader.getSystemResourceAsStream(name);
                    return ris;
                }
                InputStream ris = cl.getResourceAsStream(name);
                return ris;
            }
        });
    }
    
    boolean getFileExists(final File f) {
        return (boolean)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return Boolean.valueOf(f.exists());
            }
        });
    }
    
    long getLastModified(final File f) {
        return (long)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return Long.valueOf(f.lastModified());
            }
        });
    }
    
    private SecuritySupport() {
    }
    
    static {
        securitySupport = new SecuritySupport();
    }
}
